@@ -47,6 +47,7 @@
 
 #define DEFAULT_SINGLE_ROW         FALSE
 #define DEFAULT_ALIGN_LEFT         FALSE
+#define DEFAULT_SQUARE_ICONS       FALSE
 #define DEFAULT_EXCLUDED_MODULES   NULL
 #define DEFAULT_ORIENTATION        GTK_ORIENTATION_HORIZONTAL
 #define DEFAULT_PANEL_ORIENTATION  GTK_ORIENTATION_HORIZONTAL
@@ -79,6 +80,7 @@ struct _IndicatorConfig
 
   gboolean         single_row;
   gboolean         align_left;
+  gboolean         square_icons;
   gboolean         mode_whitelist;
   GHashTable      *blacklist;
   GHashTable      *whitelist;
@@ -100,6 +102,7 @@ enum
   PROP_0,
   PROP_SINGLE_ROW,
   PROP_ALIGN_LEFT,
+  PROP_SQUARE_ICONS,
   PROP_MODE_WHITELIST,
   PROP_BLACKLIST,
   PROP_WHITELIST,
@@ -123,6 +126,7 @@ G_DEFINE_TYPE (IndicatorConfig, indicator_config, G_TYPE_OBJECT)
 
 
 
+#ifdef XFCONF_LEGACY
 GType
 indicator_config_value_array_get_type (void)
 {
@@ -137,6 +141,7 @@ indicator_config_value_array_get_type (void)
 
   return type__volatile;
 }
+#endif
 
 
 static void
@@ -163,6 +168,13 @@ indicator_config_class_init (IndicatorConfigClass *klass)
                                                          G_PARAM_READWRITE |
                                                          G_PARAM_STATIC_STRINGS));
 
+  g_object_class_install_property (gobject_class,
+                                   PROP_SQUARE_ICONS,
+                                   g_param_spec_boolean ("square-icons", NULL, NULL,
+                                                         DEFAULT_SQUARE_ICONS,
+                                                         G_PARAM_READWRITE |
+                                                         G_PARAM_STATIC_STRINGS));
+
   g_object_class_install_property (gobject_class,
                                    PROP_MODE_WHITELIST,
                                    g_param_spec_boolean ("mode-whitelist", NULL, NULL,
@@ -220,6 +232,7 @@ indicator_config_init (IndicatorConfig *config)
 {
   config->single_row           = DEFAULT_SINGLE_ROW;
   config->align_left           = DEFAULT_ALIGN_LEFT;
+  config->square_icons         = DEFAULT_SQUARE_ICONS;
   config->mode_whitelist       = DEFAULT_MODE_WHITELIST;
   config->blacklist            = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
   config->whitelist            = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
@@ -250,6 +263,17 @@ indicator_config_finalize (GObject *object)
 
 
 
+static void
+indicator_config_free_array_element (gpointer data)
+{
+  GValue *value = (GValue *) data;
+
+  g_value_unset (value);
+  g_free (value);
+}
+
+
+
 static void
 indicator_config_collect_keys (gpointer key,
                                gpointer value,
@@ -286,26 +310,30 @@ indicator_config_get_property (GObject    *object,
       g_value_set_boolean (value, config->align_left);
       break;
 
+    case PROP_SQUARE_ICONS:
+      g_value_set_boolean (value, config->square_icons);
+      break;
+
     case PROP_MODE_WHITELIST:
       g_value_set_boolean (value, config->mode_whitelist);
       break;
 
     case PROP_BLACKLIST:
-      array = g_ptr_array_new ();
+      array = g_ptr_array_new_full (1, indicator_config_free_array_element);
       g_hash_table_foreach (config->blacklist, indicator_config_collect_keys, array);
       g_value_set_boxed (value, array);
-      xfconf_array_free (array);
+      g_ptr_array_unref (array);
       break;
 
     case PROP_WHITELIST:
-      array = g_ptr_array_new ();
+      array = g_ptr_array_new_full (1, indicator_config_free_array_element);
       g_hash_table_foreach (config->whitelist, indicator_config_collect_keys, array);
       g_value_set_boxed (value, array);
-      xfconf_array_free (array);
+      g_ptr_array_unref (array);
       break;
 
     case PROP_KNOWN_INDICATORS:
-      array = g_ptr_array_new ();
+      array = g_ptr_array_new_full (1, indicator_config_free_array_element);
       for(li = config->known_indicators; li != NULL; li = li->next)
         {
           tmp = g_new0 (GValue, 1);
@@ -314,7 +342,7 @@ indicator_config_get_property (GObject    *object,
           g_ptr_array_add (array, tmp);
         }
       g_value_set_boxed (value, array);
-      xfconf_array_free (array);
+      g_ptr_array_unref (array);
       break;
 
     default:
@@ -358,6 +386,15 @@ indicator_config_set_property (GObject      *object,
         }
       break;
 
+    case PROP_SQUARE_ICONS:
+      val = g_value_get_boolean (value);
+      if (config->square_icons != val)
+        {
+          config->square_icons = val;
+          g_signal_emit (G_OBJECT (config), indicator_config_signals [CONFIGURATION_CHANGED], 0);
+        }
+      break;
+
     case PROP_MODE_WHITELIST:
       val = g_value_get_boolean (value);
       if (config->mode_whitelist != val)
@@ -400,8 +437,7 @@ indicator_config_set_property (GObject      *object,
       break;
 
     case PROP_KNOWN_INDICATORS:
-      g_list_foreach (config->known_indicators, (GFunc) g_free, NULL);
-      g_list_free (config->known_indicators);
+      g_list_free_full (config->known_indicators, g_free);
       config->known_indicators = NULL;
       array = g_value_get_boxed (value);
       if (G_LIKELY (array != NULL))
@@ -448,6 +484,17 @@ indicator_config_get_align_left (IndicatorConfig *config)
 
 
 
+gboolean
+indicator_config_get_square_icons (IndicatorConfig *config)
+{
+  g_return_val_if_fail (XFCE_IS_INDICATOR_CONFIG (config), DEFAULT_SQUARE_ICONS);
+
+  return config->square_icons;
+}
+
+
+
+
 void
 indicator_config_set_orientation (IndicatorConfig  *config,
                                   GtkOrientation    panel_orientation,
@@ -549,7 +596,7 @@ indicator_config_get_panel_size (IndicatorConfig *config)
 gchar**
 indicator_config_get_excluded_modules (IndicatorConfig *config)
 {
-  g_return_val_if_fail (XFCE_IS_INDICATOR_CONFIG (config), DEFAULT_ALIGN_LEFT);
+  g_return_val_if_fail (XFCE_IS_INDICATOR_CONFIG (config), NULL);
 
   return config->excluded_modules;
 }
@@ -762,6 +809,10 @@ indicator_config_new (const gchar     *property_base)
       xfconf_g_property_bind (channel, property, G_TYPE_BOOLEAN, config, "align-left");
       g_free (property);
 
+      property = g_strconcat (property_base, "/square-icons", NULL);
+      xfconf_g_property_bind (channel, property, G_TYPE_BOOLEAN, config, "square-icons");
+      g_free (property);
+
       property = g_strconcat (property_base, "/mode-whitelist", NULL);
       xfconf_g_property_bind (channel, property, G_TYPE_BOOLEAN, config, "mode-whitelist");
       g_free (property);
