@@ -443,7 +443,7 @@ indicator_dialog_clear_clicked (GtkWidget       *button,
   g_return_if_fail (GTK_IS_LIST_STORE (dialog->store));
 
   if (xfce_dialog_confirm (GTK_WINDOW (gtk_widget_get_toplevel (button)),
-                           "edit-clear", NULL, NULL,
+                           "edit-clear", _("Clear"), NULL,
                            _("Are you sure you want to clear the list of "
                              "known indicators?")))
     {
@@ -495,16 +495,18 @@ indicator_dialog_build (IndicatorDialog *dialog)
 
       object = gtk_builder_get_object (builder, "checkbutton-align-left");
       g_return_if_fail (GTK_IS_WIDGET (object));
-      //exo_mutual_binding_new (G_OBJECT (dialog->config), "align-left",
-      //                        G_OBJECT (object), "active");
       g_object_bind_property (G_OBJECT (dialog->config), "align-left",
                               G_OBJECT (object), "active",
                               G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
 
+      object = gtk_builder_get_object (builder, "checkbutton-square-icons");
+      g_return_if_fail (GTK_IS_WIDGET (object));
+      g_object_bind_property (G_OBJECT (dialog->config), "square-icons",
+                              G_OBJECT (object), "active",
+                              G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
+
       object = gtk_builder_get_object (builder, "checkbutton-whitelist");
       g_return_if_fail (GTK_IS_WIDGET (object));
-      //exo_mutual_binding_new (G_OBJECT (dialog->config), "mode-whitelist",
-      //                        G_OBJECT (object), "active");
       g_object_bind_property (G_OBJECT (dialog->config), "mode-whitelist",
                               G_OBJECT (object), "active",
                               G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
@@ -547,7 +549,7 @@ indicator_dialog_build (IndicatorDialog *dialog)
     }
   else
     {
-      g_critical ("Faild to construct the builder: %s.",
+      g_critical ("Failed to construct the builder: %s.",
                   error->message);
       g_error_free (error);
     }
